about summary refs log tree commit diff
path: root/pkgs/development/compilers/gcc-4.5/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/development/compilers/gcc-4.5/default.nix')
-rw-r--r--pkgs/development/compilers/gcc-4.5/default.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkgs/development/compilers/gcc-4.5/default.nix b/pkgs/development/compilers/gcc-4.5/default.nix
index a86c317e265d0..4c449fc781faf 100644
--- a/pkgs/development/compilers/gcc-4.5/default.nix
+++ b/pkgs/development/compilers/gcc-4.5/default.nix
@@ -252,8 +252,8 @@ stdenv.mkDerivation ({
         )
       )
     }
-    ${ # Trick that should be taken out once we have a mips64-linux not loongson2f
-      if cross == null && stdenv.system == "mips64-linux" then "--with-arch=loongson2f" else ""}
+    ${ # Trick that should be taken out once we have a mips64el-linux not loongson2f
+      if cross == null && stdenv.system == "mips64el-linux" then "--with-arch=loongson2f" else ""}
     ${if langAda then " --enable-libada" else ""}
     ${if (cross == null && stdenv.isi686) then "--with-arch=i686" else ""}
     ${if cross != null then crossConfigureFlags else ""}